#!/bin/perl -w

##########################################################
#
# HMDB extract for Sanofi RC2 metabolite dictionary load
#
# Reads synonyms and foodb id
# May add others, or limit number of synonyms accepted
#
# Be careful about same name tags in other elements.
# XML files are nested with 2 space indents
#
# Download http://www.hmdb.ca/system/downloads/current/hmdb_metabolites.zip
# mkdir hmdb_metabolites
# cd hmdb_metabolites
# unzip ../hmdb_metabolites.zip
#
##########################################################

$top = "./hmdb_metabolites";
opendir(DIR, $top) || die "Failed to open directory";

open(OUT, ">metabolite-dictionary.tsv") || die "Cannot open output file";
foreach $file (readdir(DIR)) {
    if($file =~ /^[.]/) {next}
    if($file !~ /(.*)[.]xml$/) {print "Skip '$file'\n";next}
    $fileid = $1;
    $fullname = "$top/$file";

    open(IN, $fullname) || die "Failed to open $fullname";
    $dosecaccess = 0;
    $secaccess = "";
    $synonyms = "";
    $id = $fileid;
    $doids = 1;
    while(<IN>) {
	if(/<taxonomy>/) {$doids=0}
	if(/<\/taxonomy>/) {$doids=1}
	if(/<ontology>/) {$doids=0}
	if(/<\/ontology>/) {$doids=1}
	if(/<experimental_properties>/) {$doids=0}
	if(/<\/experimental_properties>/) {$doids=1}
	if(/<predicted_properties>/) {$doids=0}
	if(/<\/predicted_properties>/) {$doids=1}
	if(/<spectra>/) {$doids=0}
	if(/<\/spectra>/) {$doids=1}
	if(/<pathways>/) {$doids=0}
	if(/<\/pathways>/) {$doids=1}
	if(/<normal_concentrations>/) {$doids=0}
	if(/<\/normal_concentrations>/) {$doids=1}
	if($doids) {
	    if(/<secondary_accessions>/) {$dosecaccess=1}
	    if(/<\/secondary_accessions>/) {$dosecaccess=0}
	    if(/<accession>(^[<]+)<\/accession>/) {
		$sec = $1;
		if($dosecaccess) {
		    $secaccess .= "$sec ";
		}
		else {
		    $id = $sec;
		    if($sec ne $fileid) {print STDERR "File $file had id $sec\n"}
		}
	    }
	    if(/^  <name>([^<]+)<\/name>/) {$name = $1}
#	    if(/<description>([^<]+)<\/description>/) {$desc = $1}
	    if(/<synonym>([^<]+)<\/synonym>/) {
		$syn = $1;
		$synonyms .= "$syn;";
	    }
	    if(/<foodb_id>([^<]+)<\/foodb_id>/) {
		$syn = $1;
		$synonyms .= "$syn;";
	    }
	}
#other IDs that are not just numbers can go here
    }
    $secaccess =~ s/ $//g;
    $synonyms =~ s/;$//g;
    print OUT "$id\t$name\t$secaccess\t$synonyms\n";
}

close OUT;
